//
//  SITLocationRequest.h
//  SitumSDK
//
//  Created by A Barros on 27/2/17.
//  Copyright © 2017 Situm. All rights reserved.
//

#import <Foundation/Foundation.h>

#import "SITBeaconFilter.h"

/**
 *  SITLocationPriority
 *
 *  @discussion: Represent the tradeoff between battery comsumption and accuracy (Coming soon).
 */
typedef NS_ENUM(int, SITLocationPriority){

    kSITHighAccuracy = 0,
    
    kSITBalancedPowerAccuracy,
    
    kSITLowPower
};

/**
 *  SITLocationProvider
 *
 *  @discussion: Multiple providers can determined the location. You can force to work with one. (Coming soon).
 */
typedef NS_ENUM(int, SITLocationProvider){
    /**
     *  Localization can use the best provider available at any given moment (default).
     */
    kSITHybridProvider = 0,
    
    /**
     *  Use only cloud provider.
     */
    kSITCloudProvider,
    
    /**
     Use only phone provider. (coming soon).
     */
    kSITInPhoneProvider
};

/**
 *  SITRealtimeUpdateInterval
 *
 *  @discussion: The interval indicating how often positions will be uploaded to realtime
 */
typedef NS_ENUM(NSInteger, SITRealtimeUpdateInterval) {
    kSITUpdateIntervalRealtime = 1,
    kSITUpdateIntervalFast = 5,
    kSITUpdateIntervalNormal = 15,
    kSITUpdateIntervalSlow = 25,
    kSITUpdateIntervalBatterySaver = 1800
};

/**
 A data object that contains parameters for the location service (SITLocationManager)
 */
@interface SITLocationRequest : NSObject <NSCopying> 


/**
 One of SITLocationPriority (coming soon).
 */
@property (nonatomic, readwrite) SITLocationPriority priority;


/**
 One of SITLocationProvider (coming soon).
 */
@property (nonatomic, readwrite) SITLocationProvider provider;


/**
 The time interval indicating how often the position should be uploaded to realtime. Deprecated, use realtimeUpdateInterval instead.
 */
@property (nonatomic, readwrite) NSInteger updateInterval DEPRECATED_MSG_ATTRIBUTE("Use realtimeUpdateInterval instead");

/**
 The time interval indicating how often the position should be uploaded to realtime.
 */
@property (nonatomic, readonly) SITRealtimeUpdateInterval realtimeUpdateInterval;


/**
* (EXPERIMENTAL) Set if you want to use dead reckoning to get fast position updates using only
* the inertial sensors, between the server position updates.
 */
@property (nonatomic, readwrite) BOOL useDeadReckoning;


/**
 * Set if you want to use Gps for positioning indoor.
 */
@property (nonatomic, readwrite) BOOL useGps;


/**
 Unique identifier of the building in which you want to locate a user. (This property is mandatory).
 */
@property (nonatomic, strong) NSString *buildingID;


/**
 The thread where the location updates will be provided. If not provided, the main thread will be used.
 */
@property (nonatomic, strong) NSOperationQueue *operationQueue;


/**
 Additional options to modify the internal operation of the Location provider (private usage only).
 */
@property (nonatomic, strong) NSDictionary *options;

/**
 Custom UUIDs. The system will scan beacons with those uuids
 */
@property (nonatomic, strong) NSArray<SITBeaconFilter *> *beaconFilters;

/**
 Constructor.
 
 @param buildingId Unique identifier of the building in which you want to locate a user.
 
 @return Initialized SITLocationRequest object.
 */
- (instancetype) initWithBuildingId: (NSString*) buildingId;

/**
Setter.
 
 @param useDeadReckoning Boolean value indicating if deadReckoning should be used.
 */
- (void) setUseDeadReckoning: (BOOL) useDeadReckoning;

/**
 Setter.
 
 @param useGps Boolean value indicating if gps positioning should be used.
 */
- (void) setUseGps: (BOOL) useGps;

/**
 Setter.
 
 @param updateInterval Integer value indicating how often the position should be upload to realtime. Deprecated, use setRealtimeUpdateInterval instead.
 */
- (void) setUpdateInterval: (NSInteger) updateInterval DEPRECATED_MSG_ATTRIBUTE("Use setRealtimeUpdateInterval instead");

/**
 Setter.
 
 @param realtimeUpdateInterval SITRealtimeUpdateInterval value indicating how often the position should be upload to realtime.
 */
- (void) setRealtimeUpdateInterval: (SITRealtimeUpdateInterval) realtimeUpdateInterval;

/**
 Constructor.

 @param priority one of SITLocationPriority
 @param provider one of SITLocationProvider
 @param updateInterval The time interval at which location will be uploaded to realtime
 @param buildingID unique identifier of the building in which you want to locate a user. (This property is mandatory).
 @param operationQueue the thread where the location updates will be provided. If not provided, the main thread will be used.
 @param options additional options to modify the internal operation of the Location provider (private usage only).
 @return initialized object.
 */
- (instancetype)initWithPriority:(SITLocationPriority)priority
                provider:(SITLocationProvider)provider
                  updateInterval:(NSInteger)updateInterval
                      buildingID:(NSString *)buildingID
                  operationQueue:(NSOperationQueue *)operationQueue
                         options:(NSDictionary *)options DEPRECATED_MSG_ATTRIBUTE("Use base constructor instead");

/**
 Constructor.
 
 @param priority one of SITLocationPriority
 @param provider one of SITLocationProvider
 @param updateInterval The time interval at which location will be uploaded to realtime
 @param buildingID unique identifier of the building in which you want to locate a user. (This property is mandatory).
 @param operationQueue the thread where the location updates will be provided. If not provided, the main thread will be used.
 @param useDeadReckoning determines if dead reckoning should be used
 @param options additional options to modify the internal operation of the Location provider (private usage only).
 @return initialized object.
 */
- (instancetype)initWithPriority:(SITLocationPriority)priority
                        provider:(SITLocationProvider)provider
                  updateInterval:(NSInteger)updateInterval
                      buildingID:(NSString *)buildingID
                  operationQueue:(NSOperationQueue *)operationQueue
                useDeadReckoning:(BOOL)useDeadReckoning
                         options:(NSDictionary *)options DEPRECATED_MSG_ATTRIBUTE("Use base constructor instead");


/**
 Check if the request is valid.

 @return BOOL value that indicates if the request is valid (YES) or not (NO).
 */
- (BOOL)isValid;


@end
